@@ -4,6 +4,7 @@ from dataclasses import dataclass
 class Config:
     color_off = (0, 0, 0)
     color_on = (255, 255, 255)
+    clock_rate = 500
 
     @property
     def color_scheme(self):
@@ -16,3 +17,11 @@ class Config:
         off, on = scheme.split(':')
         self.color_off = tuple(int(a) for a in off.split(','))
         self.color_on = tuple(int(a) for a in on.split(','))
+
+    @property
+    def clock_period(self):
+        return 1/self.clock_rate
+
+    @clock_period.setter
+    def clock_period(self, period):
+        self.clock_rate = 1/period
